@@ -2,8 +2,9 @@
 `tsugu_api` 向 Tsugu 后端 API 请求模块
 '''
 
-from . import settings as settings
-from . import utils as utils
+from tsugu_api_core.utils import *
+
+import tsugu_api_core.settings as settings
 
 from ._user import get_user_data as get_user_data
 from ._user import change_user_data as change_user_data
